==> haskell-aeson-qq-0.8.2-75-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-7uyDVdSH5gSIOIISbDwyWk
key: aeson-qq-0.8.2-7uyDVdSH5gSIOIISbDwyWk
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: a93940cd7f92cf3da5fb0dd09fb8c6e5
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-7uyDVdSH5gSIOIISbDwyWk
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    text-1.2.3.0 attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6 parsec-3.1.13.0
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-JlPdAnAj9ZTLD7urCfAbfX
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             aeson-1.4.1.0-GPUdiNXlyQm9pSbB9CFKk6=22145541f26b56c63b48572ec79b9cbd
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-JlPdAnAj9ZTLD7urCfAbfX=953dd7a712b992d3cd3dd7ed7e6723e4
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-qq-0.8.2-77-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-qq.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-qq
version: 0.8.2
id: aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp
key: aeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
author: Oscar Finnsson
homepage: https://github.com/sol/aeson-qq#readme
synopsis: JSON quasiquoter for Haskell
description:
    @aeson-qq@ provides a JSON quasiquoter for Haskell.
    .
    This package exposes the function `aesonQQ` that compile-time
    converts a string representation of a JSON value into a
    `Data.Aeson.Value`.  `aesonQQ` has the signature
    .
    >aesonQQ :: QuasiQuoter
    .
    Consult the @README@ for documentation:
    <https://github.com/sol/aeson-qq#readme>
category: JSON
abi: 823db2627ee15b8cf84252b183fa65af
exposed: True
exposed-modules:
    Data.Aeson.QQ
hidden-modules: Data.JSON.QQ Paths_aeson_qq
import-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/aeson-qq-0.8.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/aeson-qq-0.8.2
hs-libraries: HSaeson-qq-0.8.2-HwnP6R8G9EmCgv7SCmfehp
depends:
    base-4.11.1.0 base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ
    text-1.2.3.0 attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE
    scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl
    vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq
    aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX parsec-3.1.13.0
    template-haskell-2.13.0.0
    haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             base-compat-0.10.4-9FtFg9E90S5CFRyvxjUaaZ=d7511a9b0b5b14c2ec3659e1cd285aec
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             attoparsec-0.13.2.2-4MFu4FwP8md1mPYCeCzsdE=4221e97be581adbf81c2554dcbaa8ab5
             scientific-0.3.6.2-IBbwozwBAuO8Adqyj8FlXl=15b9d897726264a79d0c84c8eea548d3
             vector-0.12.0.1-1fezwShzdEfG3Hp1Pmvjkq=8ec9732a4c43da9ed60d7a7b8971b540
             aeson-1.4.1.0-CAtUrtPFyRJHgUU1AjW5xX=25adaf2f506e44c8d5bd8da34f9279d5
             parsec-3.1.13.0=3626e7cedd22de76a8b10339d955721a
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             haskell-src-meta-0.8.0.3-CxBfmRqT01jLfpwXm4KU0I=f0d8e3117ecce07c9354fb2d80f0abe7
haddock-interfaces: /usr/share/doc/haskell-aeson-qq/html/aeson-qq.haddock
haddock-html: /usr/share/doc/haskell-aeson-qq/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
